<?php

/**
 * Smarty plugin
 * -------------------------------------------------------------
 * File:     function.txt.php
 * Type:     function
 * Name:     txt
 * Purpose:  outputs txt
 * -------------------------------------------------------------
 */

/**
 * @param $params
 * @param Smarty_Internal_Template $template
 * @return string
 */

function smarty_function_txt($params, Smarty_Internal_Template $template) {

    $texte = new Texte();

    $tags = [];

    if (array_key_exists('tags', $params)) {
        $tags = array_merge($tags, $params['tags']);
    }

    $tags = array_merge($tags, array_diff_key($params, array_flip(['key', 'value', 'tags'])));

    if(empty($params['key'])) {
        $params['key'] = generate_key($params['value']);
    }

    $category = $template->getTemplateVars('template');

    if (!empty($params['template'])) {
        $category = $params['template'];
    }

    $value = $texte->getOneOrCreate($params['key'], $params['value'], $category);

    if (!empty($tags)) {
        $value = $texte->replaceTag($value, $tags);
    }

    return $value;
}


/**
 * @param $value    texte dans la langue par defaut
 * @return string   la clé pour de la gestion des textes
 */
function generate_key($value)
{
    $value = strip_tags($value);
    $key = trim(mb_strtolower($value));

    $table = array(
        'Š' => 'S', 'š' => 's', 'Đ' => 'D', 'đ' => 'd', 'Ž' => 'Z', 'ž' => 'z', 'Č' => 'C', 'č' => 'c', 'Ć' => 'C', 'ć' => 'c',
        'À' => 'A', 'Á' => 'A', 'Â' => 'A', 'Ã' => 'A', 'Ä' => 'A', 'Å' => 'A', 'Æ' => 'A', 'Ç' => 'C', 'È' => 'E', 'É' => 'E',
        'Ê' => 'E', 'Ë' => 'E', 'Ì' => 'I', 'Í' => 'I', 'Î' => 'I', 'Ï' => 'I', 'Ñ' => 'N', 'Ò' => 'O', 'Ó' => 'O', 'Ô' => 'O',
        'Õ' => 'O', 'Ö' => 'O', 'Ø' => 'O', 'Ù' => 'U', 'Ú' => 'U', 'Û' => 'U', 'Ü' => 'U', 'Ý' => 'Y', 'Þ' => 'B', 'ß' => 'Ss',
        'à' => 'a', 'á' => 'a', 'â' => 'a', 'ã' => 'a', 'ä' => 'a', 'å' => 'a', 'æ' => 'a', 'ç' => 'c', 'è' => 'e', 'é' => 'e',
        'ê' => 'e', 'ë' => 'e', 'ì' => 'i', 'í' => 'i', 'î' => 'i', 'ï' => 'i', 'ð' => 'o', 'ñ' => 'n', 'ò' => 'o', 'ó' => 'o',
        'ô' => 'o', 'õ' => 'o', 'ö' => 'o', 'ø' => 'o', 'ù' => 'u', 'ú' => 'u', 'û' => 'u', 'ý' => 'y', 'þ' => 'b',
        'ÿ' => 'y', 'Ŕ' => 'R', 'ŕ' => 'r', ' - ' => '-', ' ' => '_', '&' => 'et', 'œ' => 'oe', "'" => '', '"' => ''
    );

    $key = strtr($key, $table);

    $key = preg_replace('/[^a-z0-9-_]/', '', $key);

    return $key;
}